@@ -63,6 +63,11 @@ CK_CPPSTART
 
 #include <sys/types.h>
 
+#if defined(_MSC_VER)
+/* define pid_t for Windows, as it is needed later */
+#define pid_t int
+#endif /* _MSC_VER */
+
 /*
  * Used to create the linker script for hiding lib-local symbols. Shall
  * be put directly in front of the exported symbol.
@@ -81,7 +86,7 @@ CK_CPPSTART
 /* check version numbers */
 
 #define CHECK_MAJOR_VERSION (0)
-#define CHECK_MINOR_VERSION (11)
+#define CHECK_MINOR_VERSION (12)
 #define CHECK_MICRO_VERSION (0)
 
 CK_DLL_EXP extern int CK_EXPORT check_major_version;
@@ -385,7 +390,7 @@ CK_DLL_EXP void CK_EXPORT tcase_fn_start(const char *fname, const char *file,
  *
  * @since 0.11.0
  */
-CK_DLL_EXP const char* CK_EXPORT tcase_name();
+CK_DLL_EXP const char* CK_EXPORT tcase_name(void);
 
 /**
  * Start a unit test with START_TEST(unit_name), end with END_TEST.
@@ -683,7 +688,7 @@ CK_DLL_EXP void CK_EXPORT _ck_assert_failed(const char *file, int line,
   TP _ck_x = (X); \
   TP _ck_y = (Y); \
   ck_assert_msg(_ck_x OP _ck_y, \
-  "Assertion '%s' failed: %s == %.*"TM"g, %s == %.*"TM"g", \
+  "Assertion '%s' failed: %s == %.*" TM "g, %s == %.*" TM "g", \
   #X" "#OP" "#Y, \
   #X, (int)CK_FLOATING_DIG, _ck_x, \
   #Y, (int)CK_FLOATING_DIG, _ck_y); \
@@ -695,7 +700,7 @@ CK_DLL_EXP void CK_EXPORT _ck_assert_failed(const char *file, int line,
 do { \
   TP _ck_x = (X); \
   ck_assert_msg(isfinite(_ck_x), \
-    "Assertion '%s' failed: %s == %.*"TM"g", \
+    "Assertion '%s' failed: %s == %.*" TM "g", \
     #X" is finite", \
     #X, (int)CK_FLOATING_DIG, _ck_x); \
 } while (0)
@@ -706,7 +711,7 @@ do { \
 do { \
   TP _ck_x = (X); \
   ck_assert_msg(isinf(_ck_x), \
-    "Assertion '%s' failed: %s == %.*"TM"g", \
+    "Assertion '%s' failed: %s == %.*" TM "g", \
     #X" is infinite", \
     #X, (int)CK_FLOATING_DIG, _ck_x); \
 } while (0)
@@ -717,7 +722,7 @@ do { \
 do { \
   TP _ck_x = (X); \
   ck_assert_msg(isnan(_ck_x), \
-    "Assertion '%s' failed: %s == %.*"TM"g", \
+    "Assertion '%s' failed: %s == %.*" TM "g", \
     #X" is NaN", \
     #X, (int)CK_FLOATING_DIG, _ck_x); \
 } while (0)
@@ -728,7 +733,7 @@ do { \
 do { \
   TP _ck_x = (X); \
   ck_assert_msg(!isnan(_ck_x), \
-    "Assertion '%s' failed: %s == %.*"TM"g", \
+    "Assertion '%s' failed: %s == %.*" TM "g", \
     #X" is not NaN", \
     #X, (int)CK_FLOATING_DIG, _ck_x); \
 } while (0)
@@ -741,7 +746,7 @@ do { \
   TP _ck_y = (Y); \
   TP _ck_t = (T); \
   ck_assert_msg((_ck_x - _ck_y) OP _ck_t * (D), \
-  "Assertion '%s' failed: %s == %.*"TM"g, %s == %.*"TM"g, %s == %.*"TM"g", \
+  "Assertion '%s' failed: %s == %.*" TM "g, %s == %.*" TM "g, %s == %.*" TM "g", \
   #X" "#OP"= "#Y", error < "#T, \
   #X, (int)CK_FLOATING_DIG, _ck_x, \
   #Y, (int)CK_FLOATING_DIG, _ck_y, \
@@ -757,7 +762,7 @@ do { \
   TP _ck_y = (Y); \
   TP _ck_t = (T); \
   ck_assert_msg(fabsl(_ck_y - _ck_x) OP _ck_t, \
-    "Assertion '%s' failed: %s == %.*"TM"g, %s == %.*"TM"g, %s == %.*"TM"g", \
+    "Assertion '%s' failed: %s == %.*" TM "g, %s == %.*" TM "g, %s == %.*" TM "g", \
     "fabsl("#Y" - "#X") "#OP" "#T, \
     #X, (int)CK_FLOATING_DIG, _ck_x, \
     #Y, (int)CK_FLOATING_DIG, _ck_y, \
@@ -961,7 +966,7 @@ do { \
  *
  * @since 0.11.0
  */
-#define ck_assert_float_nonnan(X) _ck_assert_floating_nonnan(X, float, "l")
+#define ck_assert_float_nonnan(X) _ck_assert_floating_nonnan(X, float, "")
 
 /**
  * Check two double precision floating point numbers to determine if X == Y
@@ -975,7 +980,7 @@ do { \
  *
  * @since 0.11.0
  */
-#define ck_assert_double_eq(X, Y) _ck_assert_floating(X, ==, Y, double, "l")
+#define ck_assert_double_eq(X, Y) _ck_assert_floating(X, ==, Y, double, "")
 /**
  * Check two double precision floating point numbers to determine if X != Y
  *
@@ -988,7 +993,7 @@ do { \
  *
  * @since 0.11.0
  */
-#define ck_assert_double_ne(X, Y) _ck_assert_floating(X, !=, Y, double, "l")
+#define ck_assert_double_ne(X, Y) _ck_assert_floating(X, !=, Y, double, "")
 /**
  * Check two double precision floating point numbers to determine if X < Y
  *
@@ -1001,7 +1006,7 @@ do { \
  *
  * @since 0.11.0
  */
-#define ck_assert_double_lt(X, Y) _ck_assert_floating(X, <, Y, double, "l")
+#define ck_assert_double_lt(X, Y) _ck_assert_floating(X, <, Y, double, "")
 /**
  * Check two double precision floating point numbers to determine if X <= Y
  *
@@ -1014,7 +1019,7 @@ do { \
  *
  * @since 0.11.0
  */
-#define ck_assert_double_le(X, Y) _ck_assert_floating(X, <=, Y, double, "l")
+#define ck_assert_double_le(X, Y) _ck_assert_floating(X, <=, Y, double, "")
 /**
  * Check two double precision floating point numbers to determine if X > Y
  *
@@ -1027,7 +1032,7 @@ do { \
  *
  * @since 0.11.0
  */
-#define ck_assert_double_gt(X, Y) _ck_assert_floating(X, >, Y, double, "l")
+#define ck_assert_double_gt(X, Y) _ck_assert_floating(X, >, Y, double, "")
 /**
  * Check two double precision floating point numbers to determine if X >= Y
  *
@@ -1040,7 +1045,7 @@ do { \
  *
  * @since 0.11.0
  */
-#define ck_assert_double_ge(X, Y) _ck_assert_floating(X, >=, Y, double, "l")
+#define ck_assert_double_ge(X, Y) _ck_assert_floating(X, >=, Y, double, "")
 
 /**
  * Check two double precision floating point numbers to determine if X≈Y
@@ -1056,7 +1061,7 @@ do { \
  *
  * @since 0.11.0
  */
-#define ck_assert_double_eq_tol(X, Y, T)  _ck_assert_floating_absdiff_op_tol(X, Y, <, T, double, "l")
+#define ck_assert_double_eq_tol(X, Y, T)  _ck_assert_floating_absdiff_op_tol(X, Y, <, T, double, "")
 
 /**
  * Check two double precision floating point numbers to determine if not X≈Y
@@ -1072,7 +1077,7 @@ do { \
  *
  * @since 0.11.0
  */
-#define ck_assert_double_ne_tol(X, Y, T) _ck_assert_floating_absdiff_op_tol(X, Y, >=, T, double, "l")
+#define ck_assert_double_ne_tol(X, Y, T) _ck_assert_floating_absdiff_op_tol(X, Y, >=, T, double, "")
 
 /**
  * Check two double precision floating point numbers to determine if X>≈Y
@@ -1088,7 +1093,7 @@ do { \
  *
  * @since 0.11.0
  */
-#define ck_assert_double_ge_tol(X, Y, T) _ck_assert_floating_op_tol(X, >, Y, T, -1, double, "l")
+#define ck_assert_double_ge_tol(X, Y, T) _ck_assert_floating_op_tol(X, >, Y, T, -1, double, "")
 
 /**
  * Check two double precision floating point numbers to determine if X<≈Y
@@ -1104,7 +1109,7 @@ do { \
  *
  * @since 0.11.0
  */
-#define ck_assert_double_le_tol(X, Y, T) _ck_assert_floating_op_tol(X, <, Y, T, 1, double, "l")
+#define ck_assert_double_le_tol(X, Y, T) _ck_assert_floating_op_tol(X, <, Y, T, 1, double, "")
 
 /**
  * Check that a double precision floating point number is finite; i.e. is
@@ -1118,7 +1123,7 @@ do { \
  *
  * @since 0.11.0
  */
-#define ck_assert_double_finite(X) _ck_assert_floating_finite(X, double, "l")
+#define ck_assert_double_finite(X) _ck_assert_floating_finite(X, double, "")
 
 /**
  * Check that a double precision floating point number is infinite,
@@ -1132,7 +1137,7 @@ do { \
  *
  * @since 0.11.0
  */
-#define ck_assert_double_infinite(X) _ck_assert_floating_infinite(X, double, "l")
+#define ck_assert_double_infinite(X) _ck_assert_floating_infinite(X, double, "")
 
 /**
  * Check that a double precision floating point number
@@ -1146,7 +1151,7 @@ do { \
  *
  * @since 0.11.0
  */
-#define ck_assert_double_nan(X) _ck_assert_floating_nan(X, double, "l")
+#define ck_assert_double_nan(X) _ck_assert_floating_nan(X, double, "")
 
 /**
  * Check that a double precision floating point number is
@@ -1160,7 +1165,7 @@ do { \
  *
  * @since 0.11.0
  */
-#define ck_assert_double_nonnan(X) _ck_assert_floating_nonnan(X, double, "l")
+#define ck_assert_double_nonnan(X) _ck_assert_floating_nonnan(X, double, "")
 
 /** 
  * Check two double precision floating point numbers to determine if X == Y
@@ -2259,6 +2264,23 @@ CK_DLL_EXP pid_t CK_EXPORT check_fork(void);
  */
 CK_DLL_EXP void CK_EXPORT check_waitpid_and_exit(pid_t pid) CK_ATTRIBUTE_NORETURN;
 
+/**
+ * Set the maximal assertion message size.
+ *
+ * This protects the code against unintentional extremely large assertion messages
+ * (values of up to 4GB were seen in the wild).
+ * The usual size for a message is less than 80 bytes.
+ *
+ * If the environment variable CK_MAX_MSG_SIZE is defined to a positive value, it is used.
+ * Otherwise, if a positive maximal message size is set via this function, it is used.
+ * Otherwise, the maximal message size is one assigned at compile time (4K bytes).
+ *
+ * @param max_msg_size the maximal assertion message size.
+ *
+ * @since 0.12.0
+ */
+CK_DLL_EXP void CK_EXPORT check_set_max_msg_size(size_t max_msg_size);
+
 #ifdef __cplusplus
 CK_CPPEND
 #endif
